@@ -556,7 +556,7 @@ int main (int argc, char *argv[]) {
 			"is allowed for superuser only");
 
 
-	if (first_hop > max_hops)
+	if (!first_hop || first_hop > max_hops)
 		ex_error ("first hop out of range");
 	if (max_hops > MAX_HOPS)
 		ex_error ("max hops cannot be more than " _TEXT(MAX_HOPS));
@@ -639,7 +639,7 @@ int main (int argc, char *argv[]) {
 static void print_header (void) {
 
 	/*  Note, without ending new-line!  */
-	printf ("traceroute to %s (%s), %u hops max, %u byte packets",
+	printf ("traceroute to %s (%s), %u hops max, %zu byte packets",
 				dst_name, addr2str (&dst_addr), max_hops,
 				header_len + data_len);
 	fflush (stdout);
@@ -663,7 +663,8 @@ static void print_addr (sockaddr_any *res) {
 	    buf[0] = '\0';
 	    getnameinfo (&res->sa, sizeof (*res), buf, sizeof (buf),
 							    0, 0, NI_IDN);
-	    /*  foo on errors.  */
+	    /*  to be robast...  */
+	    if (!buf[0])  strncpy (buf, str, sizeof (buf));
 
 	    printf (" %s (%s)", buf, str);
 	}
